%define name	pmud
%define version	0.7.1
%define release	1mdk

Summary:	Power Manager daemon for Apple Powerbooks
Name:		%{name}
Version:	%{version}
Release:	%{release}
Source0:	pmud-%{version}.tar.bz2
Source1:	batmon.16.xpm.bz2
Source2:	batmon.32.xpm.bz2
Source3:	batmon.48.xpm.bz2
Patch0:		pmud-kver-mdk.patch.bz2
# Add option "sysconfig" to trackpad to read /etc/sysconfig/mouse
# TRACKPAD_TAP=(yes|no)
Patch1:		pmud-0.7-sysconfig.patch.bz2
# add code "12" to /etc/power/pwrctl for iBook2 sleep
Patch2:		pmud-0.7-add-ibook2-sleep.patch.bz2
# cure ibook2 trackpad "jitters" on wake from sleep
Patch3:		pmud-0.7.1-ibook2-jitters.patch.bz2
License:	GPL
URL:		http://www3.jvc.nl/linuxppc
Group:		Monitoring
BuildRoot:	%{_tmppath}/%{name}-buildroot
Provides:	apmd
Prereq:		/sbin/chkconfig
# Batmon requires tcl/tk
Requires:	tcl, tk
ExclusiveArch:	ppc

%description 
Pmud is a daemon which periodically polls the PMU (power manager) and
performs functions such as enabling or disabling devices appropriately
when the power source changes. It can also be instructed to signal
init(8) that a power-failure has occured.

%prep

%setup -q -n pmud-0.7
%patch0 -p1 -b .kver
%patch1 -p1 -b .sysconfig
%patch2 -p1 -b .ibook2
%patch3 -p1

%build
%serverbuild
%make CC=gcc CFLAGS="$RPM_OPT_FLAGS"

%install
rm -fr $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT/sbin
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_initrddir}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/power
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man8

install -m 0744 pwrctl $RPM_BUILD_ROOT%{_sysconfdir}/power
install -m 0644 power.conf $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/power
install -m 0755 pmud.rc $RPM_BUILD_ROOT%{_initrddir}/pmud

# install file but lowercase'ize its name first
InstallFile() {
	source="$1" perms="$2" directory="$3"
	target=`echo $source | tr '[A-Z]' '[a-z]'`
	install -m $perms $source $directory/$target
}

(for file in pmud wakebay snooze fblevel trackpad; do
	InstallFile $file 0755 $RPM_BUILD_ROOT/sbin
done)

(for file in xmouse Batmon backlight; do
	InstallFile $file 0755 $RPM_BUILD_ROOT%{_bindir}
done)

(for file in pmud.8 snooze.8 fblevel.8 batmon.8 xmouse.8; do
	InstallFile $file 0644 $RPM_BUILD_ROOT%{_mandir}/man8
done)
	
(cd $RPM_BUILD_ROOT%{_bindir}; ln -sf ../../sbin/snooze apm)

# mdk icons
mkdir -p $RPM_BUILD_ROOT%{_miconsdir}
mkdir -p $RPM_BUILD_ROOT%{_iconsdir}
mkdir -p $RPM_BUILD_ROOT%{_liconsdir}

bzcat %SOURCE1 > $RPM_BUILD_ROOT%{_miconsdir}/batmon.xpm
bzcat %SOURCE2 > $RPM_BUILD_ROOT%{_iconsdir}/batmon.xpm
bzcat %SOURCE3 > $RPM_BUILD_ROOT%{_liconsdir}/batmon.xpm

# mdk menus
mkdir -p $RPM_BUILD_ROOT%{_menudir}

cat << EOF > $RPM_BUILD_ROOT%{_menudir}/batmon
?package(pmud):command="/usr/bin/batmon" icon="batmon.xpm" \
	needs="X11" section="Applications/Monitoring" title="Batmon" \
	longtitle="Battery life monitor for Apple Powerbooks"
EOF

%clean
rm -rf $RPM_BUILD_ROOT

%pre 
[ -c /dev/pmu ] || {
	echo "creating /dev/pmu"
	mknod /dev/pmu c 10 154
}

%post 
%_post_service pmud
%update_menus

%preun
%_preun_service pmud

%postun
%clean_menus

%files
%defattr(-,root,root)
#
%doc TODO
%doc BUGS
%doc README
%doc INSTALL
%doc CHANGES
%doc THANKS
%doc pwrctl-local
#
%{_mandir}/man8/pmud.8*
%{_mandir}/man8/snooze.8*
%{_mandir}/man8/fblevel.8*
%{_mandir}/man8/batmon.8*
%{_mandir}/man8/xmouse.8*
#
%config(noreplace) %{_sysconfdir}/sysconfig/power
%config(noreplace) %{_sysconfdir}/power/pwrctl
%config(noreplace) %{_initrddir}/pmud 
#
%{_menudir}/batmon
%{_miconsdir}/batmon*
%{_iconsdir}/batmon*
%{_liconsdir}/batmon*
#
/sbin/pmud
/sbin/snooze
/sbin/wakebay
/sbin/fblevel
/sbin/trackpad
#
%{_bindir}/xmouse
%{_bindir}/batmon
%{_bindir}/backlight
%{_bindir}/apm

%changelog
* Fri Nov  9 2001 Stew Benedict <sbenddict@mandrakesoft.com> 0.7.1-1mdk
- new version, patch for ibook2 trackpad "jitters" after wakeup

* Sat Oct  6 2001 Stew Benedict <sbenedict@mandrakesoft.com> 0.7-4mdk
- add code "12" for iBook2 sleep support in /etc/pwr/pwrctl
- thanks to Henrik Edlund <henrik@edlund.org>

* Mon Aug  6 2001 Stew Benedict <sbenedict@mandrakesoft.com> 0.7-3mdk
- chmod 0744 /etc/power/pwrctl (bugzilla #3968)

* Tue May 29 2001 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.7-2mdk
- sanitized specfile (s/Copyright/License, server macros, menus, icons)
- added option "sysconfig" to trackpad: tapping can now be enabled from
  /etc/sysconfig/mouse. Usage: TRACKPAD_TAP=(yes|no)
- added missing %{_sysconfdir}/sysconfig/power
- made file names all lowercase
- made %{_initrddir}/pmud executable
- moved some binaries (trackpad -> /sbin, batmon -> /usr/bin)

* Wed May 16 2001 Stew Benedict <sbenedict@mandrakesoft.com> 0.7-1mdk
- first Mandrake RPM, cleanup spec, patch source for kernel version
- patch to build contribs, remove debug from trackpad, reload option - pmud

